@@ -46,8 +46,26 @@ class Tag(Entity):
         ]
 
     @staticmethod
-    def create_global_tags_aspect(tags: List[str]) -> models.GlobalTagsClass:
-        """Create a `models.TagAssociationClass` instance."""
-        return models.GlobalTagsClass(
-            tags=[models.TagAssociationClass(builder.make_tag_urn(tag)) for tag in tags]
+    def create_mpc_association(
+        entity_type: str, entity_urn: str, tags: List[str]
+    ) -> dict:
+        """Create an MPC tags association dictionary.
+
+        Args:
+            entity_type: The entity type.
+            entity_urn: The entity URN.
+            tags: The list of tags.
+
+        Return: The MPC dictionary.
+        """
+        return Tag._create_mpc_dict(
+            entity_type,
+            entity_urn,
+            "globalTags",
+            models.GlobalTagsClass(
+                tags=[
+                    models.TagAssociationClass(builder.make_tag_urn(tag))
+                    for tag in tags
+                ]
+            ),
         )
